arrc.losses.center\_loss
========================

.. automodule:: arrc.losses.center_loss

   
   .. rubric:: Classes

   .. autosummary::
   
      CenterBasedLoss
      CenterLoss
      CenterTripletLoss
      CenterTripletLossWrapper
   